==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/MetricAlertSingleResourceMultipleMetricCriteriaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.MetricAlertSingleResourceMultipleMetricCriteriaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Specifies the metric alert criteria for a single resource that has multiple metric criteria.
 * @property allOf The list of metric criteria for this 'all of' operation.
 * @property odataType specifies the type of the alert criteria.
 * Expected value is 'Microsoft.Azure.Monitor.SingleResourceMultipleMetricCriteria'.
 */
public data class MetricAlertSingleResourceMultipleMetricCriteriaArgs(
    public val allOf: Output<List<MetricCriteriaArgs>>? = null,
    public val odataType: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.insights.inputs.MetricAlertSingleResourceMultipleMetricCriteriaArgs> {
    override fun toJava():
        com.pulumi.azurenative.insights.inputs.MetricAlertSingleResourceMultipleMetricCriteriaArgs =
        com.pulumi.azurenative.insights.inputs.MetricAlertSingleResourceMultipleMetricCriteriaArgs.builder()
            .allOf(allOf?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .odataType(odataType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MetricAlertSingleResourceMultipleMetricCriteriaArgs].
 */
@PulumiTagMarker
public class MetricAlertSingleResourceMultipleMetricCriteriaArgsBuilder internal constructor() {
    private var allOf: Output<List<MetricCriteriaArgs>>? = null

    private var odataType: Output<String>? = null

    /**
     * @param value The list of metric criteria for this 'all of' operation.
     */
    @JvmName("datddxcbidmhtpum")
    public suspend fun allOf(`value`: Output<List<MetricCriteriaArgs>>) {
        this.allOf = value
    }

    @JvmName("kqlitoinugkmgkxu")
    public suspend fun allOf(vararg values: Output<MetricCriteriaArgs>) {
        this.allOf = Output.all(values.asList())
    }

    /**
     * @param values The list of metric criteria for this 'all of' operation.
     */
    @JvmName("amsufdlluqnletpg")
    public suspend fun allOf(values: List<Output<MetricCriteriaArgs>>) {
        this.allOf = Output.all(values)
    }

    /**
     * @param value specifies the type of the alert criteria.
     * Expected value is 'Microsoft.Azure.Monitor.SingleResourceMultipleMetricCriteria'.
     */
    @JvmName("geuaabttfmatbhck")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The list of metric criteria for this 'all of' operation.
     */
    @JvmName("jdjealnivkwsvhgw")
    public suspend fun allOf(`value`: List<MetricCriteriaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allOf = mapped
    }

    /**
     * @param argument The list of metric criteria for this 'all of' operation.
     */
    @JvmName("ddfegeenhqkpdjal")
    public suspend fun allOf(argument: List<suspend MetricCriteriaArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MetricCriteriaArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param argument The list of metric criteria for this 'all of' operation.
     */
    @JvmName("frlcwgvrbhlyaaha")
    public suspend fun allOf(vararg argument: suspend MetricCriteriaArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            MetricCriteriaArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param argument The list of metric criteria for this 'all of' operation.
     */
    @JvmName("uxbpyuxvnmmdfvli")
    public suspend fun allOf(argument: suspend MetricCriteriaArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MetricCriteriaArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param values The list of metric criteria for this 'all of' operation.
     */
    @JvmName("axsuifndsrdfuata")
    public suspend fun allOf(vararg values: MetricCriteriaArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allOf = mapped
    }

    /**
     * @param value specifies the type of the alert criteria.
     * Expected value is 'Microsoft.Azure.Monitor.SingleResourceMultipleMetricCriteria'.
     */
    @JvmName("taevkjohkbakmxft")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    internal fun build(): MetricAlertSingleResourceMultipleMetricCriteriaArgs =
        MetricAlertSingleResourceMultipleMetricCriteriaArgs(
            allOf = allOf,
            odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/MetricAlertSingleResourceMultipleMetricCriteriaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.MetricAlertSingleResourceMultipleMetricCriteriaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Specifies the metric alert criteria for a single resource that has multiple metric criteria.
 * @property allOf The list of metric criteria for this 'all of' operation.
 * @property odataType specifies the type of the alert criteria.
 * Expected value is 'Microsoft.Azure.Monitor.SingleResourceMultipleMetricCriteria'.
 */
public data class MetricAlertSingleResourceMultipleMetricCriteriaArgs(
    public val allOf: Output<List<MetricCriteriaArgs>>? = null,
    public val odataType: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.insights.inputs.MetricAlertSingleResourceMultipleMetricCriteriaArgs> {
    override fun toJava():
        com.pulumi.azurenative.insights.inputs.MetricAlertSingleResourceMultipleMetricCriteriaArgs =
        com.pulumi.azurenative.insights.inputs.MetricAlertSingleResourceMultipleMetricCriteriaArgs.builder()
            .allOf(allOf?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .odataType(odataType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MetricAlertSingleResourceMultipleMetricCriteriaArgs].
 */
@PulumiTagMarker
public class MetricAlertSingleResourceMultipleMetricCriteriaArgsBuilder internal constructor() {
    private var allOf: Output<List<MetricCriteriaArgs>>? = null

    private var odataType: Output<String>? = null

    /**
     * @param value The list of metric criteria for this 'all of' operation.
     */
    @JvmName("oyhwhdxfpmmlcoyv")
    public suspend fun allOf(`value`: Output<List<MetricCriteriaArgs>>) {
        this.allOf = value
    }

    @JvmName("xaryrqtxdurpxhkj")
    public suspend fun allOf(vararg values: Output<MetricCriteriaArgs>) {
        this.allOf = Output.all(values.asList())
    }

    /**
     * @param values The list of metric criteria for this 'all of' operation.
     */
    @JvmName("agaqrhjejjfkyybf")
    public suspend fun allOf(values: List<Output<MetricCriteriaArgs>>) {
        this.allOf = Output.all(values)
    }

    /**
     * @param value specifies the type of the alert criteria.
     * Expected value is 'Microsoft.Azure.Monitor.SingleResourceMultipleMetricCriteria'.
     */
    @JvmName("klcerrbanwrnykeo")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The list of metric criteria for this 'all of' operation.
     */
    @JvmName("cpsxjdqjhcfoeand")
    public suspend fun allOf(`value`: List<MetricCriteriaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allOf = mapped
    }

    /**
     * @param argument The list of metric criteria for this 'all of' operation.
     */
    @JvmName("egerqgmaofctmxfv")
    public suspend fun allOf(argument: List<suspend MetricCriteriaArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MetricCriteriaArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param argument The list of metric criteria for this 'all of' operation.
     */
    @JvmName("ikaqnqbiarnbeaxr")
    public suspend fun allOf(vararg argument: suspend MetricCriteriaArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            MetricCriteriaArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param argument The list of metric criteria for this 'all of' operation.
     */
    @JvmName("vlrgxprrofmhxukl")
    public suspend fun allOf(argument: suspend MetricCriteriaArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MetricCriteriaArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param values The list of metric criteria for this 'all of' operation.
     */
    @JvmName("ixdjvvjbeifbqbrq")
    public suspend fun allOf(vararg values: MetricCriteriaArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allOf = mapped
    }

    /**
     * @param value specifies the type of the alert criteria.
     * Expected value is 'Microsoft.Azure.Monitor.SingleResourceMultipleMetricCriteria'.
     */
    @JvmName("cmmcxfrdvivmbtyv")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    internal fun build(): MetricAlertSingleResourceMultipleMetricCriteriaArgs =
        MetricAlertSingleResourceMultipleMetricCriteriaArgs(
            allOf = allOf,
            odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        )
}
